@@ -97,7 +97,9 @@ def square(t, size, fill=True, flag=True):
     '''
     if fill:
         t.begin_fill()
+
     for x in range(4):
+
         t.fd(size)
         if flag:
             t.right(90)
@@ -447,7 +449,7 @@ def row(t, func, size=10, anim=False):
         _row(t, func, size)
 
 
-def getpen(color='black'):
+def getpen(color='black', fillcolor=None):
     '''
     获得一支画笔
 
@@ -470,7 +472,9 @@ def getpen(color='black'):
         'mb': (0, -SCR_H / 2)
     }
     t.ht()
-    t.color(color)
+    t.pencolor(color)
+    if fillcolor:
+        t.fillcolor(fillcolor)
     t.speed(0)
     return t
 
